==> litejs-0.13.0.tgz: package/public/views/components/material.js <==

!function(Mediator) {
	var openMenu, lastMenuTarget
	, tooltip = El.to(El("pre.tooltip"), document.body)
	, tick, wait
	, ripple = El(".waves-ripple")

	El.near = near
	function near(source, target, x, y, margin) {
		var top, left
		, rect = target.getBoundingClientRect()
		if (x == "left") {
			left = rect.left - (source.offsetWidth) - margin
			x = "150%"
		} else if (x == "leftEdge") {
			left = rect.left - margin
			x = "0%"
		} else if (x == "right") {
			left = rect.left + rect.width + margin
			x = "-50%"
		} else if (x == "rightEdge") {
			left = rect.left - source.offsetWidth + rect.width + margin
			x = "100%"
		} else {
			// svg elements dont have offsetWidth
			left = rect.left + (rect.width / 2) - (source.offsetWidth/2)
			x = "50%"
		}
		if (y == "top") {
			top = rect.top - source.offsetHeight - margin
			y = " 150%"
		} else if (y == "bottom") {
			top = rect.top + rect.height + margin
			y = " -50%"
		} else {
			top = rect.top + (rect.height / 2) - (source.offsetHeight/2)
			y = " 50%"
		}
		left += El.scrollLeft()
		top += El.scrollTop()
		El.css(source, "transform-origin", x + y)
		El.css(source, "top", (top < 0 ? 0 : top) + "px")
		El.css(source, "left", (left < 0 ? 0 : left) + "px")
	}
	El.on(document.body, "mouseover", function(e) {
		var x, y
		, target = e.target
		, text = target.getAttribute("data-tooltip")
		El.rmClass(tooltip, "is-visible")
		if (!text) return
		El.append(El.empty(tooltip), text)
		if (El.hasClass(target, "tooltip--left")) {
			x = "left"
		} else if (El.hasClass(target, "tooltip--right")) {
			x = "right"
		} else if (El.hasClass(target, "tooltip--top")) {
			y = "top"
		} else {
			y = "bottom"
		}
		near(tooltip, target, x, y, 4)
		setTimeout(function() {
			El.addClass(tooltip, "is-visible")
		}, 0)
	})
	function closeMenu(e) {
		if (e && e.target == lastMenuTarget) return
		var menu = openMenu
		if (menu) {
			El.rmClass(menu, "is-visible")
			setTimeout(El.kill.bind(null, menu), 800)
		}
		if (lastMenuTarget) {
			El.rmClass(lastMenuTarget, "is-active")
		}
		openMenu = null
	}
	Mediator.on("resize", closeMenu)
	Mediator.on("showMenu", function(target, menu, x, y, margin, e) {
		Event.stop(e)
		var close = openMenu && lastMenuTarget == target
		closeMenu()
		if (close) return
		lastMenuTarget = target
		openMenu = El.render(El.to(El(menu), document.body))
		near(openMenu, target, x, y, 4)
		El.addClass(target, "is-active")
		setTimeout(function() {
			El.addClass(openMenu, "is-visible")
		}, 0)
	})
	El.on(document.body, "mouseup", closeMenu)

	El.on(document.body, "mousedown", function(e) {
		var target = e.target
		if (!El.hasClass(target, "waves") || target.disabled) return
		var rect = target.getBoundingClientRect()
		, top = e.clientY - rect.top
		, left = e.clientX - rect.left
		, maxH = Math.max(top, target.offsetHeight - top)
		, maxW = Math.max(left, target.offsetWidth - left)
		, max = Math.sqrt(maxH * maxH + maxW * maxW)
		, size = (2 * max) + "px"
		El.css(ripple, "top", (top - max) + "px")
		El.css(ripple, "left", (left - max) + "px")
		El.css(ripple, "width", size)
		El.css(ripple, "height", size)
		El.to(ripple, target)
		clearTimeout(tick)
		end()
		wait = 1
		tick = setTimeout(end, 800)
		El.one(document.body, "mouseup", end)
		setTimeout(function() {
			El.addClass(ripple, "waves-ripple--play")
		}, 0)
	})
	function end() {
		if (!(wait--)) {
			El.rmClass(ripple, "waves-ripple--play")
		}
	}
}(Mediator)

==> litejs-0.14.2.tgz: package/public/views/components/material.js <==

!function(Mediator) {
	var openMenu, lastMenuTarget
	, tooltip = El.to(El("pre.tooltip"), document.body)
	, tick, wait
	, ripple = El(".waves-ripple")

	El.near = near
	function near(source, target, x, y, margin) {
		var top, left
		, rect = target.getBoundingClientRect()
		// svg elements dont have offsetWidth, IE8 does not have rect.width
		, width = rect.width || target.offsetWidth || 0
		, height = rect.height || target.offsetHeight || 0
		if (x == "left") {
			left = rect.left - source.offsetWidth - margin
			x = "150%"
		} else if (x == "leftEdge") {
			left = rect.left - margin
			x = "0%"
		} else if (x == "right") {
			left = rect.left + width + margin
			x = "-50%"
		} else if (x == "rightEdge") {
			left = rect.left - source.offsetWidth + width + margin
			x = "100%"
		} else {
			left = rect.left + (width / 2) - (source.offsetWidth/2)
			x = "50%"
		}
		if (y == "top") {
			top = rect.top - source.offsetHeight - margin
			y = " 150%"
		} else if (y == "bottom") {
			top = rect.top + height + margin
			y = " -50%"
		} else {
			top = rect.top + (height / 2) - (source.offsetHeight/2)
			y = " 50%"
		}
		left += El.scrollLeft()
		top += El.scrollTop()
		El.css(source, "transform-origin", x + y)
		El.css(source, "top", (top < 0 ? 0 : top) + "px")
		El.css(source, "left", (left < 0 ? 0 : left) + "px")
	}
	El.on(document.body, "mouseover", function(e) {
		var x, y
		, target = e.target
		, text = target.getAttribute("data-tooltip")
		El.rmClass(tooltip, "is-visible")
		if (!text) return
		El.append(El.empty(tooltip), text)
		if (El.hasClass(target, "tooltip--left")) {
			x = "left"
		} else if (El.hasClass(target, "tooltip--right")) {
			x = "right"
		} else if (El.hasClass(target, "tooltip--top")) {
			y = "top"
		} else {
			y = "bottom"
		}
		near(tooltip, target, x, y, 4)
		setTimeout(function() {
			El.addClass(tooltip, "is-visible")
		}, 0)
	})
	function closeMenu(e) {
		if (e && e.target == lastMenuTarget) return
		var menu = openMenu
		if (menu) {
			El.rmClass(menu, "is-visible")
			setTimeout(El.kill.bind(null, menu), 800)
		}
		if (lastMenuTarget) {
			El.rmClass(lastMenuTarget, "is-active")
		}
		openMenu = null
	}
	Mediator.on("resize", closeMenu)
	Mediator.on("showMenu", function(target, menu, x, y, margin, e) {
		Event.stop(e)
		var close = openMenu && lastMenuTarget == target
		closeMenu()
		if (close) return
		lastMenuTarget = target
		openMenu = El.render(El.to(El(menu), document.body))
		near(openMenu, target, x, y, 4)
		El.addClass(target, "is-active")
		setTimeout(function() {
			El.addClass(openMenu, "is-visible")
		}, 0)
	})
	El.on(document.body, "mouseup", closeMenu)

	El.on(document.body, "mousedown", function(e) {
		var target = e.target
		if (!El.hasClass(target, "waves") || target.disabled) return
		var rect = target.getBoundingClientRect()
		, top = e.clientY - rect.top
		, left = e.clientX - rect.left
		, maxH = Math.max(top, target.offsetHeight - top)
		, maxW = Math.max(left, target.offsetWidth - left)
		, max = Math.sqrt(maxH * maxH + maxW * maxW)
		, size = (2 * max) + "px"
		El.css(ripple, "top", (top - max) + "px")
		El.css(ripple, "left", (left - max) + "px")
		El.css(ripple, "width", size)
		El.css(ripple, "height", size)
		El.to(ripple, target)
		clearTimeout(tick)
		end()
		wait = 1
		tick = setTimeout(end, 800)
		El.one(document.body, "mouseup", end)
		setTimeout(function() {
			El.addClass(ripple, "waves-ripple--play")
		}, 0)
	})
	function end() {
		if (!(wait--)) {
			El.rmClass(ripple, "waves-ripple--play")
		}
	}
}(Mediator)
